@@ -1,4 +1,4 @@
-###############################################################################
+###########################################################################
 #    Authors     : Lionel VICTOR <lionel.victor@unforgettable.com>
 #                                 <lionel.victor@free.fr>
 #                  Ludovic ROUSSEAU <ludovic.rousseau@free.fr>
@@ -24,9 +24,9 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #
-###############################################################################
+###########################################################################
 
-# $Id: PCSC.pm,v 1.22 2010-08-18 21:05:41 rousseau Exp $
+# $Id: PCSC.pm,v 1.24 2011-03-06 15:51:42 rousseau Exp $
 
 package Chipcard::PCSC;
 
@@ -156,18 +156,6 @@ sub Cancel($)
 	return _Cancel ($self->{hContext});
 }
 
-sub SetTimeout($)
-{
-	my $self = shift;
-	confess ("wrong type") unless ref $self;
-
-	my $timeout = shift;
-	# Defult time out is 30 seconds
-	$timeout = 30 unless (defined $timeout);
-
-	return _SetTimeout ($self->{hContext}, $timeout);
-}
-
 sub DESTROY($)
 {
 	my $self = shift;
